@@ -1,6 +1,7 @@
 from past.builtins import basestring
 import argparse
 import os.path
+import pathlib
 import re
 import errno
 from datetime import datetime
@@ -57,8 +58,8 @@ session_modality_re = re.compile(r'\w+_\w+_([A-Z]+)\d+')
 server_name_re = re.compile(r'(https?://)?([\w\-\.]+).*')
 
 
-def connect(server=None, user=None, loglevel='ERROR', connection=None,
-            use_netrc=True, failures=0, password=None):
+def connect(server=None, user=None, loglevel='ERROR', logger=logger,
+            connection=None, use_netrc=True, failures=0, password=None):
     """
     Opens a connection to an XNAT instance
 
@@ -156,8 +157,8 @@ def connect(server=None, user=None, loglevel='ERROR', connection=None,
         warnings.simplefilter('ignore')
         try:
             connection = xnat.connect(server, loglevel=loglevel,
-                                      **kwargs)
-        except ValueError:  # Login failed
+                                      logger=logger, **kwargs)
+        except (ValueError, KeyError):  # Login failed
             if password is None:
                 msg = ("The user access token for {} stored in "
                        "{} has expired!".format(server, netrc_path))
@@ -578,3 +579,8 @@ def set_logger(level=logging.INFO):
     handler.setFormatter(formatter)
     logger.addHandler(handler)
     return logger
+
+
+def split_extension(fpath):
+    ext = ''.join(pathlib.Path(fpath).suffixes)
+    return fpath[:-len(ext)], ext
